#! /bin/bash
# -------------------------------------------------------------------
# ckbs: Constrained Kalman-Bucy Smoother Program: Copyright (C) 2006
# Authors: Bradlely Bell:        bradbell at washington dot edu
#          Gianluigi Pillonetto: giapi at dei dot unipd dot it
# License: GNU General Public License Version 2
# ----------------------------------------------------------------------------
# check initial working directory
dir=`pwd | sed -e 's|.*/||'`
if [ "$dir" != "trunk" ]
then
	echo "new_stable.sh: must execute this script in the trunk"
	exit 1
fi
#
echo "Getting current revision number for version of trunk"
rev_trunk=`svn info --revision HEAD | \
	grep '^Revision:' | sed -e 's|^Revision: *||'`
echo "rev_trunk=$rev_trunk"
#
# number for the stable version we are creating
stable_version=`date +%F |sed -e 's/-//g' -e 's|^|0.|'`
#
# check that the documentation is up to date
doc_version=`grep '$section' ckbs.omh | \
	sed -e 's|.*ckbs-\([0-9.]\{10\}\).*|\1|'`
if [ "$doc_version" != "$stable_version" ]
then
	echo "new_stable.sh: run ./copy_doc.sh to bring doc version up to date"
	echo "new_stable.sh: stable_version = $stable_version"
	echo "new_stable.sh: doc_version    = $doc_version"
	exit 1
fi
#
# web address for trunk, stable, and release
repository="https://projects.coin-or.org/svn/CoinBazaar"
rep_trunk="$repository/projects/ckbs/trunk"
rep_stable="$repository/projects/ckbs/stable/$stable_version"
rep_release="$repository/projects/ckbs/releases/$stable_version.0"
rep_html="$repository/html/ckbs"
#
# create the new stable version
msg="[ckbs/stable] Create ckbs/stable/$stable_version 
from ckbs/trunk at revision $rev_trunk."
echo "svn copy $rep_trunk $rep_stable -m \"$msg\""
if ! svn copy  $rep_trunk $rep_stable -m "$msg"
then
	"new_stable.sh: Cannot create $rep_stable"
	exit 1
fi
#
# add a copy of the documentation to the stable version
msg="[ckbs/stable] Add documentation corresponding to this stable version"
echo "svn copy $rep_html $rep_stable/doc -m \"$msg\""
if ! svn copy $rep_html $rep_stable/doc -m "$msg"
then
	"new_stable.sh: Cannot copy documentation for this stable version"
	exit 1
fi
#
# create the new release version
msg="[ckbs/releases] Create ckbs/releases/$stable_version.0 
from ckbs/trunk at revision $rev_trunk."
echo "svn copy $rep_stable $rep_release -m \"$msg\""
if ! svn copy  $rep_stable $rep_release -m "$msg"
then
	"new_stable.sh: Cannot create $rep_release"
	exit 1
fi
echo ""
echo "To check out this stable version use the command:"
echo "	svn_checkout.sh ckbs stable/$stable_version"
echo "To check out this release version use the command:"
echo "	svn_checkout.sh ckbs releases/$stable_version.0"
